@@ -275,9 +275,9 @@ SvAppletObject::SvAppletObject()
         pSoApp->pAppletVerbList = new SvVerbList();
         // Alle unterstuetzten Verben anlegen
         pSoApp->pAppletVerbList->Append(
-                SvVerb( 0, String( SoResId( STR_VERB_OPEN ) ) ) );
+                SvVerb( 0, SoResId( STR_VERB_OPEN ).toString() ) );
         pSoApp->pAppletVerbList->Append(
-                SvVerb( SVVERB_PROPS, String( SoResId( STR_VERB_PROPS ) ) ) );
+                SvVerb( SVVERB_PROPS, SoResId( STR_VERB_PROPS ).toString() ) );
         pSoApp->nAppletDocFormat = SOT_FORMATSTR_ID_APPLETOBJECT;
     }
     // Verben der Superklasse bekanntgeben, um GetVerbs nicht
@@ -625,9 +625,12 @@ BOOL SvAppletObject::Load
         if( nVer == APPLET_VERS )
         {
             *xStm >> pImpl->aCmdList;
-            xStm->ReadByteString( pImpl->aClass, RTL_TEXTENCODING_ASCII_US );
-            xStm->ReadByteString( pImpl->aName, RTL_TEXTENCODING_ASCII_US );
-            xStm->ReadByteString( pImpl->aCodeBase, RTL_TEXTENCODING_ASCII_US );
+            pImpl->aClass = read_lenPrefixed_uInt8s_ToOUString<sal_uInt16>(*xStm,
+                RTL_TEXTENCODING_ASCII_US );
+            pImpl->aName = read_lenPrefixed_uInt8s_ToOUString<sal_uInt16>(*xStm,
+                RTL_TEXTENCODING_ASCII_US);
+            pImpl->aCodeBase = read_lenPrefixed_uInt8s_ToOUString<sal_uInt16>(*xStm,
+                RTL_TEXTENCODING_ASCII_US);
             *xStm >> pImpl->bMayScript;
         }
         else
