@@ -788,17 +788,6 @@ void Container::ImpInsert( void* p, CBlock* pBlock, sal_uInt16 nIndex )
 |*
 *************************************************************************/
 
-void Container::Insert( void* p )
-{
-    ImpInsert( p, pCurBlock, nCurIndex );
-}
-
-/*************************************************************************
-|*
-|*    Container::Insert()
-|*
-*************************************************************************/
-
 void Container::Insert( void* p, sal_uIntPtr nIndex )
 {
     if ( nCount <= nIndex )
@@ -903,21 +892,6 @@ void* Container::ImpRemove( CBlock* pBlock, sal_uInt16 nIndex )
 |*
 *************************************************************************/
 
-void* Container::Remove()
-{
-    // Wenn kein Item vorhanden ist, NULL zurueckgeben
-    if ( !nCount )
-        return NULL;
-    else
-        return ImpRemove( pCurBlock, nCurIndex );
-}
-
-/*************************************************************************
-|*
-|*    Container::Remove()
-|*
-*************************************************************************/
-
 void* Container::Remove( sal_uIntPtr nIndex )
 {
     // Ist Index nicht innerhalb des Containers, dann NULL zurueckgeben
