@@ -29,10 +29,7 @@
 #define _ANIMATION
 #define ITEMID_GRF_CROP 0
 
-#ifndef SVX_LIGHT
 #include <bf_so3/lnkbase.hxx>
-#else
-#endif
 
 #include <math.h>
 #include <vcl/salbtype.hxx>
@@ -67,8 +64,6 @@ namespace binfilter {
 
 #define GRAFSTREAMPOS_INVALID 0xffffffff
 
-#ifndef SVX_LIGHT
-
 // ------------------
 // - SdrGraphicLink -
 // ------------------
@@ -158,26 +153,6 @@ namespace binfilter {
 /*N*/   }
 /*N*/ }
 
-#else
-
-/*?*/ GraphicFilter* SVX_LIGHT_pGrapicFilter = NULL;
-/*?*/
-/*?*/ GraphicFilter* GetGrfFilter()
-/*?*/ {
-/*?*/   if( !SVX_LIGHT_pGrapicFilter )
-/*?*/     {
-/*?*/       const SvtPathOptions aPathOptions;
-/*?*/
-/*?*/         SVX_LIGHT_pGrapicFilter = new GraphicFilter( FALSE );
-/*?*/         SVX_LIGHT_pGrapicFilter->SetFilterPath( aPathOptions.GetFilterPath() );
-/*?*/     }
-/*?*/
-/*?*/   return SVX_LIGHT_pGrapicFilter;
-/*?*/ }
-
-
-#endif // SVX_LIGHT
-
 // --------------
 // - SdrGrafObj -
 // --------------
@@ -326,8 +301,6 @@ namespace binfilter {
 
 /*N*/ void SdrGrafObj::ImpLinkAnmeldung()
 /*N*/ {
-/*N*/ #ifndef SVX_LIGHT
-/*N*/
 /*N*/   SvxLinkManager* pLinkManager = pModel != NULL ? pModel->GetLinkManager() : NULL;
 /*N*/
 /*N*/   if( pLinkManager != NULL && pGraphicLink == NULL )
@@ -339,16 +312,12 @@ namespace binfilter {
 /*N*/           pGraphicLink->Connect();
 /*N*/       }
 /*N*/   }
-/*N*/
-/*N*/ #endif // SVX_LIGHT
 /*N*/ }
 
 // -----------------------------------------------------------------------------
 
 /*N*/ void SdrGrafObj::ImpLinkAbmeldung()
 /*N*/ {
-/*N*/ #ifndef SVX_LIGHT
-/*N*/
 /*N*/   SvxLinkManager* pLinkManager = pModel != NULL ? pModel->GetLinkManager() : NULL;
 /*N*/
 /*N*/   if( pLinkManager != NULL && pGraphicLink!=NULL)
@@ -357,8 +326,6 @@ namespace binfilter {
 /*?*/       pLinkManager->Remove( pGraphicLink );
 /*?*/       pGraphicLink=NULL;
 /*N*/   }
-/*N*/
-/*N*/ #endif // SVX_LIGHT
 /*N*/ }
 
 // -----------------------------------------------------------------------------
@@ -400,7 +367,6 @@ namespace binfilter {
 /*N*/ {
 /*N*/     sal_Bool  bRet = sal_False;
 /*N*/
-/*N*/ #ifndef SVX_LIGHT
 /*N*/     if( pGraphicLink )
 /*N*/     {
 /*N*/         BOOL bIsChanged = pModel->IsChanged();
@@ -409,26 +375,6 @@ namespace binfilter {
 /*N*/
 /*N*/         bRet = sal_True;
 /*N*/     }
-/*N*/ #else
-/*N*/     if( aFileName.Len() )
-/*N*/     {
-/*N*/         // #92205# Load linked graphics for player
-/*N*/         SvStream* pIStm = ::utl::UcbStreamHelper::CreateStream( aFileName, STREAM_READ | STREAM_SHARE_DENYNONE );
-/*N*/
-/*N*/         if( pIStm )
-/*N*/         {
-/*N*/             Graphic           aGraphic;
-/*N*/             GraphicFilter*    pFilter = GetGrfFilter();
-/*N*/             USHORT            nError = pFilter->ImportGraphic( aGraphic, aFileName, *pIStm );
-/*N*/
-/*N*/             pGraphic->SetGraphic( aGraphic );
-/*N*/
-/*N*/             delete pIStm;
-/*N*/         }
-/*N*/
-/*N*/         bRet = sal_True;
-/*N*/     }
-/*N*/ #endif
 /*N*/
 /*N*/     return bRet;
 /*N*/ }
@@ -773,9 +719,7 @@ namespace binfilter {
 /*N*/               }
 /*N*/           }
 /*N*/
-/*N*/ #ifndef SVX_LIGHT
 /*N*/           pBmp = new Bitmap( ResId ( BMAP_GrafikEi, *ImpGetResMgr() ) );
-/*N*/ #endif
 /*N*/       }
 /*N*/
 /*N*/       ImpPaintReplacement( pOutDev, aText, pBmp, bFill );
@@ -924,21 +868,20 @@ namespace binfilter {
 /*N*/   if(rHead.GetVersion() >= 8)
 /*N*/   {
 /*N*/       // UNICODE: rIn>>aFileName;
-/*N*/       rIn.ReadByteString(aFileName);
+/*N*/       aFileName = rIn.ReadUniOrByteString(rIn.GetStreamCharSet());
 /*N*/   }
 /*N*/
 /*N*/   if(rHead.GetVersion() >= 9)
 /*N*/   {
 /*N*/       // UNICODE: rIn >> aFilterName;
-/*N*/       rIn.ReadByteString(aFilterName);
+/*N*/       aFilterName = rIn.ReadUniOrByteString(rIn.GetStreamCharSet());
 /*N*/   }
 /*N*/   else
 /*?*/       aFilterName = String( RTL_CONSTASCII_USTRINGPARAM( "BMP - MS Windows" ) );
 /*N*/
 /*N*/   if( aFileName.Len() )
 /*N*/   {
-/*?*/ #ifndef SVX_LIGHT
-/*?*/       String aFileURLStr;
+/*?*/       rtl::OUString aFileURLStr;
 /*?*/
 /*?*/       if( ::utl::LocalFileHelper::ConvertPhysicalNameToURL( aFileName, aFileURLStr ) )
 /*?*/       {
@@ -954,9 +897,6 @@ namespace binfilter {
 /*?*/               delete pIStm;
 /*?*/           }
 /*?*/       }
-/*?*/ #else
-/*?*/       OSL_FAIL("SdrGrafObj::ReadDataTilV10(): SVX_LIGHT kann keine Graphic-Links");
-/*?*/ #endif
 /*N*/   }
 /*N*/   else if( nError != 0 )
 /*?*/       rIn.SetError(nError);
@@ -1028,7 +968,7 @@ namespace binfilter {
 /*N*/       rIn >> aCropRect;
 /*N*/       rIn >> bTmp; bMirrored = bTmp;
 /*N*/
-/*N*/       rIn.ReadByteString(aName);
+/*N*/       aName = rIn.ReadUniOrByteString(rIn.GetStreamCharSet());
 /*N*/       // #85414# since there seems to be some documents wich have an illegal
 /*N*/       // character inside the name of a graphic object we have to fix this
 /*N*/       // here on load time or it will crash our xml later.
@@ -1039,7 +979,7 @@ namespace binfilter {
 /*?*/               aName.SetChar( nIndex, '?' );
 /*N*/       }
 /*N*/
-/*N*/       rIn.ReadByteString(aFileNameRel);
+/*N*/       aFileNameRel = rIn.ReadUniOrByteString(rIn.GetStreamCharSet());
 /*N*/
 /*N*/       if( aFileNameRel.Len() )
 /*N*/       {
@@ -1051,7 +991,7 @@ namespace binfilter {
 /*N*/           aFileName.Erase();
 /*N*/
 /*N*/       // UNICODE: rIn >> aFilterName;
-/*N*/       rIn.ReadByteString(aFilterName);
+/*N*/       aFilterName = rIn.ReadUniOrByteString(rIn.GetStreamCharSet());
 /*N*/
 /*N*/       rIn >> bGraphicLink;                    // auch dieses Flag ist neu in V11
 /*N*/
@@ -1303,13 +1243,8 @@ namespace binfilter {
 /*N*/           {
 /*N*/               const ULONG nSwapMode = pModel->GetSwapGraphicsMode();
 /*N*/
-/*N*/ #ifndef SVX_LIGHT
 /*N*/               if( ( ( GRAFSTREAMPOS_INVALID != nGrafStreamPos ) || pGraphic->HasUserData() || pGraphicLink ) &&
 /*N*/                   ( nSwapMode & SDR_SWAPGRAPHICSMODE_PURGE ) )
-/*N*/ #else
-/*N*/               if( ( ( GRAFSTREAMPOS_INVALID != nGrafStreamPos ) || pGraphic->HasUserData() || aFileName.Len() ) &&
-/*N*/                   ( nSwapMode & SDR_SWAPGRAPHICSMODE_PURGE ) )
-/*N*/ #endif
 /*N*/               {
 /*N*/                   pRet = NULL;
 /*N*/               }
