@@ -263,10 +263,8 @@ public:
 /*N*/   pCurPaM     =
 /*N*/   pCurNumRange= NULL;
 /*N*/   eSrcSet     = osl_getThreadTextEncoding();
-/*N*/   if( pStrm )
-/*N*/       eSrcSet = GetSOStoreTextEncoding( eSrcSet, pStrm->GetVersion() );
-/*N*/   else if( pRoot.Is() )
-/*N*/       eSrcSet = GetSOStoreTextEncoding( eSrcSet, pRoot->GetVersion() );
+/*N*/   if( pStrm || pRoot.Is() )
+/*N*/       eSrcSet = GetSOStoreTextEncoding( eSrcSet );
 /*N*/   nVersion    = SWG_VERSION;
 /*N*/
 /*N*/   aRecTypes.Remove( 0, aRecTypes.Count() );
@@ -1387,7 +1385,6 @@ void Sw3StringPool::LoadOld( SvStream& r )
 {
     aPool.DeleteAndDestroy( 0, aPool.Count() );
     sal_uInt16 n;
-    String s;
     r >> n;
     // Dieser schlimme Hack ist notwendig, da ich vergessen habe,
     // den Zeichensatz im Record zu speichern. Und kein Flag-Byte da!
@@ -1403,7 +1400,7 @@ void Sw3StringPool::LoadOld( SvStream& r )
     }
     while( n-- )
     {
-        r.ReadByteString( s, eSrcEnc );
+        String s = r.ReadUniOrByteString( eSrcEnc );
         Sw3String* p = new Sw3String( s, 0 );
         aPool.Insert( p, aPool.Count() );
     }
@@ -1421,14 +1418,12 @@ void Sw3StringPool::LoadOld( SvStream& r )
 /*N*/   // MIB 8.4.97: Datenbank-Felder enthalten ein 0xff, das auf keinen
 /*N*/   // Fall mit konvertiert werden darf. Wir erkennen sie am Wert
 /*N*/   // IDX_NOCONV_FF.
-/*N*/   rtl_TextEncoding eSrcEnc =  GetSOLoadTextEncoding( (rtl_TextEncoding)cSet,
-/*N*/                                                      r.GetVersion() );
+/*N*/   rtl_TextEncoding eSrcEnc =  GetSOLoadTextEncoding( (rtl_TextEncoding)cSet );
 /*N*/   while( n-- )
 /*N*/   {
 /*N*/       sal_uInt16 nId;
-/*N*/       ByteString s8;
 /*N*/       r >> nId;
-/*N*/       r.ReadByteString( s8 );
+/*N*/       rtl::OString s8 = read_lenPrefixed_uInt8s_ToOString<sal_uInt16>(r);
 /*N*/       if( nId == IDX_NOCONV_FF )
 /*N*/           s = Sw3IoImp::ConvertStringNoDbDelim( s8, eSrcEnc );
 /*N*/       else
@@ -1660,7 +1655,7 @@ void Sw3StringPool::LoadOld( SvStream& r )
 /*N*/ void Sw3IoImp::SetPasswd()
 /*N*/ {
 /*N*/   delete pCrypter; pCrypter = NULL;
-/*N*/   if( pRoot && pRoot->GetKey().Len() )
+/*N*/   if( pRoot && !pRoot->GetKey().isEmpty() )
 /*N*/   {
 /*?*/       pCrypter = new Crypter( pRoot->GetKey() );
 /*?*/       sal_Char buf[ 17 ];
